@@ -2,7 +2,7 @@ context("linear discrim - fda")
 
 # ------------------------------------------------------------------------------
 
-source("helper-objects.R")
+source(test_path("helper-objects.R"))
 
 # ------------------------------------------------------------------------------
 
@@ -106,7 +106,7 @@ test_that('missing data', {
 test_that('api errors', {
   expect_error(
     discrim_linear() %>% set_engine("monday"),
-    regexp = "Engine 'monday' is not available"
+    regexp = "Available engines are: 'MASS', 'mda'"
   )
 })
 
